Index: /issm/trunk-jpl/test/NightlyRun/runme.py
===================================================================
--- /issm/trunk-jpl/test/NightlyRun/runme.py	(revision 20071)
+++ /issm/trunk-jpl/test/NightlyRun/runme.py	(revision 20072)
@@ -28,5 +28,5 @@
 	                       'mesh'   : validation of mesh tests
 						   'adolc'   : validation of adolc tests
-                           'gia'   : validation of gia tests
+                           'slr'   : validation of slr tests
 
 	                       ...
@@ -53,5 +53,5 @@
 	#Process options
 	#GET benchmark {{{
-	if not ismember(benchmark,['all','nightly','ismip','eismint','thermal','mesh','validation','tranforcing','adolc','gia']):
+	if not ismember(benchmark,['all','nightly','ismip','eismint','thermal','mesh','validation','tranforcing','adolc','slr']):
 		print "runme warning: benchmark '%s' not supported, defaulting to test 'nightly'." % benchmark
 		benchmark='nightly'
@@ -116,5 +116,5 @@
 	elif strcmpi(benchmark,'referential'):
 		test_ids=test_ids.intersection(set(range(1601,1603)))
-	elif strcmpi(benchmark,'gia'):
+	elif strcmpi(benchmark,'slr'):
 		test_ids=test_ids.intersection(set(range(2001,2100)))
 	elif strcmpi(benchmark,'adolc'):

Index: /issm/trunk-jpl/test/NightlyRun/runme.m
===================================================================
--- /issm/trunk-jpl/test/NightlyRun/runme.m	(revision 20071)
+++ /issm/trunk-jpl/test/NightlyRun/runme.m	(revision 20072)
@@ -19,5 +19,5 @@
 %                      'mesh'   : validation of mesh tests
 %                      'adolc'   : validation of adolc tests
 %                      'gia'   : validation of gia tests
 %                      'qmu'   : validation of dakota tests
 %                      ...
@@ -49,5 +49,5 @@
 %GET benchmark {{{
 benchmark=getfieldvalue(options,'benchmark','nightly');
-if ~ismember(benchmark,{'all','nightly','ismip','eismint','thermal','mesh','validation','tranforcing','adolc','gia','qmu'})
+if ~ismember(benchmark,{'all','nightly','ismip','eismint','thermal','mesh','validation','tranforcing','adolc','slr','qmu'})
 	disp('runme warning: benchmark not supported, defaulting to test ''nightly''')
 	benchmark='nightly';
@@ -117,5 +117,5 @@
 elseif strcmpi(benchmark,'referential'),
 	test_ids=intersect(test_ids,[1601:1602]);
-elseif strcmpi(benchmark,'gia'),
+elseif strcmpi(benchmark,'slr'),
 	test_ids=intersect(test_ids,[2001:2100]);
 elseif strcmpi(benchmark,'adolc'),
@@ -19,5 +19,5 @@
 %                      'mesh'   : validation of mesh tests
 %                      'adolc'   : validation of adolc tests
-%                      'gia'   : validation of gia tests
+%                      'slr'   : validation of slr tests
 %                      'qmu'   : validation of dakota tests
 %                      ...